@@ -10,21 +10,9 @@
 
 #include "kpty_p.h"
 
+#include <kpty_debug.h>
 #include <QProcess>
 
-#ifdef __sgi
-#define __svr4__
-#endif
-
-#ifdef __osf__
-#define _OSF_SOURCE
-#include <float.h>
-#endif
-
-#ifdef _AIX
-#define _ALL_SOURCE
-#endif
-
 // __USE_XOPEN isn't defined by default in ICC
 // (needed for ptsname(), grantpt() and unlockpt())
 #ifdef __INTEL_COMPILER
@@ -128,7 +116,6 @@ extern "C" {
 # define _tcsetattr(fd, ttmode) ioctl(fd, TCSETS, (char *)ttmode)
 #endif
 
-#include <QDebug>
 #include <qplatformdefs.h>
 
 #include <Q_PID>
@@ -217,22 +204,14 @@ bool KPty::open()
     if (::openpty(&d->masterFd, &d->slaveFd, ptsn, nullptr, nullptr)) {
         d->masterFd = -1;
         d->slaveFd = -1;
-        qWarning() << "Can't open a pseudo teletype";
+        qCWarning(KPTY_LOG) << "Can't open a pseudo teletype";
         return false;
     }
     d->ttyName = ptsn;
 
 #else
 
-#if HAVE__GETPTY // irix
-
-    char *ptsn = _getpty(&d->masterFd, O_RDWR | O_NOCTTY, S_IRUSR | S_IWUSR, 0);
-    if (ptsn) {
-        d->ttyName = ptsn;
-        goto grantedpt;
-    }
-
-#elif HAVE_PTSNAME || defined(TIOCGPTN)
+#if HAVE_PTSNAME || defined(TIOCGPTN)
 
 #if HAVE_POSIX_OPENPT
     d->masterFd = ::posix_openpt(O_RDWR | O_NOCTTY);
@@ -276,18 +255,6 @@ bool KPty::open()
 
             d->masterFd = QT_OPEN(ptyName.data(), QT_OPEN_RDWR);
             if (d->masterFd >= 0) {
-#ifdef Q_OS_SOLARIS
-                /* Need to check the process group of the pty.
-                 * If it exists, then the slave pty is in use,
-                 * and we need to get another one.
-                 */
-                int pgrp_rtn;
-                if (ioctl(d->masterFd, TIOCGPGRP, &pgrp_rtn) == 0 || errno != EIO) {
-                    ::close(d->masterFd);
-                    d->masterFd = -1;
-                    continue;
-                }
-#endif /* Q_OS_SOLARIS */
                 if (!access(d->ttyName.data(), R_OK | W_OK)) { // checks availability based on permission bits
                     if (!geteuid()) {
                         struct group *p = getgrnam(TTY_GROUP);
@@ -307,7 +274,7 @@ bool KPty::open()
         }
     }
 
-    qWarning() << "Can't open a pseudo teletype";
+    qCWarning(KPTY_LOG) << "Can't open a pseudo teletype";
     return false;
 
 gotpty:
@@ -320,7 +287,7 @@ gotpty:
     if (((info.ownerId() != getuid()) ||
             (info.permissions() & (QFile::ReadGroup | QFile::ExeGroup | QFile::ReadOther | QFile::WriteOther | QFile::ExeOther))) &&
             !d->chownpty(true)) {
-        qWarning()
+        qCWarning(KPTY_LOG)
                 << "chownpty failed for device " << ptyName << "::" << d->ttyName
                 << "\nThis means the communication can be eavesdropped." << endl;
     }
@@ -340,29 +307,12 @@ grantedpt:
 
     d->slaveFd = QT_OPEN(d->ttyName.data(), QT_OPEN_RDWR | O_NOCTTY);
     if (d->slaveFd < 0) {
-        qWarning() << "Can't open slave pseudo teletype";
+        qCWarning(KPTY_LOG) << "Can't open slave pseudo teletype";
         ::close(d->masterFd);
         d->masterFd = -1;
         return false;
     }
 
-#if (defined(__svr4__) || defined(__sgi__) || defined(Q_OS_SOLARIS))
-    // Solaris uses STREAMS for terminal handling. It is possible
-    // for the pty handling modules to be left off the stream; in that
-    // case push them on. ioctl(fd, I_FIND, ...) is documented to return
-    // 1 if the module is on the stream already.
-    {
-        static const char *pt = "ptem";
-        static const char *ld = "ldterm";
-        if (ioctl(d->slaveFd, I_FIND, pt) == 0) {
-            ioctl(d->slaveFd, I_PUSH, pt);
-        }
-        if (ioctl(d->slaveFd, I_FIND, ld) == 0) {
-            ioctl(d->slaveFd, I_PUSH, ld);
-        }
-    }
-#endif
-
 #endif /* HAVE_OPENPTY */
 
     fcntl(d->masterFd, F_SETFD, FD_CLOEXEC);
@@ -374,13 +324,13 @@ grantedpt:
 bool KPty::open(int fd)
 {
 #if !HAVE_PTSNAME && !defined(TIOCGPTN)
-    qWarning() << "Unsupported attempt to open pty with fd" << fd;
+    qCWarning(KPTY_LOG) << "Unsupported attempt to open pty with fd" << fd;
     return false;
 #else
     Q_D(KPty);
 
     if (d->masterFd >= 0) {
-        qWarning() << "Attempting to open an already open pty";
+        qCWarning(KPTY_LOG) << "Attempting to open an already open pty";
         return false;
     }
 
@@ -398,7 +348,7 @@ bool KPty::open(int fd)
         d->ttyName = buf;
 # endif
     } else {
-        qWarning() << "Failed to determine pty slave device for fd" << fd;
+        qCWarning(KPTY_LOG) << "Failed to determine pty slave device for fd" << fd;
         return false;
     }
 
@@ -431,12 +381,12 @@ bool KPty::openSlave()
         return true;
     }
     if (d->masterFd < 0) {
-        qWarning() << "Attempting to open pty slave while master is closed";
+        qCWarning(KPTY_LOG) << "Attempting to open pty slave while master is closed";
         return false;
     }
     d->slaveFd = QT_OPEN(d->ttyName.data(), QT_OPEN_RDWR | O_NOCTTY);
     if (d->slaveFd < 0) {
-        qWarning() << "Can't open slave pseudo teletype";
+        qCWarning(KPTY_LOG) << "Can't open slave pseudo teletype";
         return false;
     }
     fcntl(d->slaveFd, F_SETFD, FD_CLOEXEC);
@@ -483,20 +433,11 @@ void KPty::setCTty()
     setsid();
 
     // make our slave pty the new controlling terminal.
-#ifdef TIOCSCTTY
     ioctl(d->slaveFd, TIOCSCTTY, 0);
-#else
-    // __svr4__ hack: the first tty opened after setsid() becomes controlling tty
-    ::close(KDE_open(d->ttyName, O_WRONLY, 0));
-#endif
 
     // make our new process group the foreground group on the pty
     int pgrp = getpid();
-#if defined(_POSIX_VERSION) || defined(__svr4__)
     tcsetpgrp(d->slaveFd, pgrp);
-#elif defined(TIOCSPGRP)
-    ioctl(d->slaveFd, TIOCSPGRP, (char *)&pgrp);
-#endif
 }
 
 void KPty::login(const char *user, const char *remotehost)
@@ -673,11 +614,6 @@ bool KPty::tcGetAttr(struct ::termios *ttmode) const
 {
     Q_D(const KPty);
 
-#ifdef Q_OS_SOLARIS
-    if (_tcgetattr(d->slaveFd, ttmode) == 0) {
-        return true;
-    }
-#endif
     return _tcgetattr(d->masterFd, ttmode) == 0;
 }
 
@@ -685,11 +621,6 @@ bool KPty::tcSetAttr(struct ::termios *ttmode)
 {
     Q_D(KPty);
 
-#ifdef Q_OS_SOLARIS
-    if (_tcsetattr(d->slaveFd, ttmode) == 0) {
-        return true;
-    }
-#endif
     return _tcsetattr(d->masterFd, ttmode) == 0;
 }
 
